@@ -91,7 +91,9 @@ test_that ("proportions only", {
                                                 proportions_only = TRUE))
   # These will only be approximately equal:
   expect_true (mean (abs (d1 - d2)) > 0)
-  expect_true (max (abs (d1 - d2)) < 0.01) # within 1%
+  if (test_all) {
+      expect_true (max (abs (d1 - d2)) < 0.01) # within 1%
+  }
 })
 
 test_that ("categorical threshold", {
